@@ -80,6 +80,10 @@ impl IpMapDataset {
             }
         }
     }
+
+    pub fn internal_ref(&self) -> (&BTreeMap<u32, Cow<'static, str>>,&BTreeMap<u128, Cow<'static, str>>) {
+        (&self.data4, &self.data6)
+    }
 }
 
 #[cfg(test)]
